==> haskell-conduit-combinators-1.1.2-41-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-combinators.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-combinators
version: 1.1.2
id: conduit-combinators-1.1.2-D9JAZ0DwD6rIseZb1qAvyh
key: conduit-combinators-1.1.2-D9JAZ0DwD6rIseZb1qAvyh
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Commonly used conduit functions, for both chunked and unchunked data
description:
    See docs and README at <http://www.stackage.org/package/conduit-combinators>
category: Data, Conduit
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Conduit Data.Conduit.Combinators Data.Conduit.Combinators.Internal
    Data.Conduit.Combinators.Stream
hidden-modules: Data.Conduit.Combinators.Unqualified
abi: 846b8bedf767de5047e4d09f79893017
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/conduit-combinators-1.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/conduit-combinators-1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/conduit-combinators-1.1.2
hs-libraries: HSconduit-combinators-1.1.2-D9JAZ0DwD6rIseZb1qAvyh
depends:
    base-4.10.1.0 base16-bytestring-0.1.1.6-Bd4rUARbKHBrsqzcqGjb8
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    bytestring-0.10.8.2 conduit-1.2.13-HPcAbWklbAX2QiAIrwnRKh
    conduit-extra-1.2.3.2-7rcuVeV5cVU6yMyz6IewPr filepath-1.4.1.2
    monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00
    mwc-random-0.13.6.0-KJiIvjcL2lWLnFThQq321j
    primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo
    resourcet-1.1.11-2ELYNE6SPdC32SQLLtn3bT
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC
    chunked-data-0.3.1-b7vpdLNXFs9Fl3TvX3KYV
    mono-traversable-1.0.8.1-IQvDArwzbFtAU926zGbfv2 unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base16-bytestring-0.1.1.6-Bd4rUARbKHBrsqzcqGjb8=37016c8c32a9f0915ad84c6171e7c01d
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             conduit-1.2.13-HPcAbWklbAX2QiAIrwnRKh=bd601a98f1a129bf3da3bb557b18ab9d
             conduit-extra-1.2.3.2-7rcuVeV5cVU6yMyz6IewPr=87a746ef23adcc6fc65850b18512f96f
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00=48449fd048b5d0ad9ccb1feb773de43b
             mwc-random-0.13.6.0-KJiIvjcL2lWLnFThQq321j=d987008159c99ec9f543473509d028a5
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=b4457a9f891c4eea587ee58a79b7f0fc
             resourcet-1.1.11-2ELYNE6SPdC32SQLLtn3bT=1d6e661a46718784bbfbe4c49289dda9
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl=34c1d6b33f33105a74600f465b68cb2b
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC=a5672067c7a1184b41916f0fb2d0c330
             chunked-data-0.3.1-b7vpdLNXFs9Fl3TvX3KYV=3ecf44f48d1d085f7a79a9f1356afb94
             mono-traversable-1.0.8.1-IQvDArwzbFtAU926zGbfv2=bdc6d2dfa21751cd13cf81ce5eaa7c86
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
haddock-html: /usr/share/doc/haskell-conduit-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-combinators-1.1.2-47-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-combinators.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-combinators
version: 1.1.2
id: conduit-combinators-1.1.2-LBwArSoKTaUBZpY5IP5G0q
key: conduit-combinators-1.1.2-LBwArSoKTaUBZpY5IP5G0q
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Commonly used conduit functions, for both chunked and unchunked data
description:
    See docs and README at <http://www.stackage.org/package/conduit-combinators>
category: Data, Conduit
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Conduit Data.Conduit.Combinators Data.Conduit.Combinators.Internal
    Data.Conduit.Combinators.Stream
hidden-modules: Data.Conduit.Combinators.Unqualified
abi: 42add66cf5f8800f1e2c36c932906514
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/conduit-combinators-1.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/conduit-combinators-1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/conduit-combinators-1.1.2
hs-libraries: HSconduit-combinators-1.1.2-LBwArSoKTaUBZpY5IP5G0q
depends:
    base-4.10.1.0 base16-bytestring-0.1.1.6-Bd4rUARbKHBrsqzcqGjb8
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    bytestring-0.10.8.2 conduit-1.2.13-KGlTp1YFxNbGMkHuibtdAg
    conduit-extra-1.2.3.2-G578KQ4JWAN4eJFOJU3rLe filepath-1.4.1.2
    monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00
    mwc-random-0.13.6.0-KJiIvjcL2lWLnFThQq321j
    primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo
    resourcet-1.1.11-3TsXMCE9bmqJOgo1a6gjl4
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC
    chunked-data-0.3.1-b7vpdLNXFs9Fl3TvX3KYV
    mono-traversable-1.0.8.1-FeSZBg8VWeC4joDdSdAsso unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base16-bytestring-0.1.1.6-Bd4rUARbKHBrsqzcqGjb8=37016c8c32a9f0915ad84c6171e7c01d
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             conduit-1.2.13-KGlTp1YFxNbGMkHuibtdAg=f28c447a2bec9bcfe4989e0ac67614c0
             conduit-extra-1.2.3.2-G578KQ4JWAN4eJFOJU3rLe=fb21443c7f8ea5a559913c5877818b98
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00=48449fd048b5d0ad9ccb1feb773de43b
             mwc-random-0.13.6.0-KJiIvjcL2lWLnFThQq321j=d987008159c99ec9f543473509d028a5
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=b4457a9f891c4eea587ee58a79b7f0fc
             resourcet-1.1.11-3TsXMCE9bmqJOgo1a6gjl4=5d5f7a5bec88091b43d999202511397f
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl=34c1d6b33f33105a74600f465b68cb2b
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC=a5672067c7a1184b41916f0fb2d0c330
             chunked-data-0.3.1-b7vpdLNXFs9Fl3TvX3KYV=3ecf44f48d1d085f7a79a9f1356afb94
             mono-traversable-1.0.8.1-FeSZBg8VWeC4joDdSdAsso=9fae7feb4e8c5f6c045f0cf15c9bae04
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
haddock-html: /usr/share/doc/haskell-conduit-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
